import { IEventBase, Injector, FUniver } from '@univerjs/core';
import { FWorkbook, FWorksheet } from '@univerjs/sheets/facade';
/**
 * @ignore
 */
export interface IFSheetCrosshairHighlightEventMixin {
    /**
     * Triggered when the crosshair highlight is enabled or disabled.
     * @example
     * ```ts
     * univerAPI.addEvent(univerAPI.Event.CrosshairHighlightEnabledChanged, (event) => {
     *     const enabled = event.enabled;
     *     const workbook = event.workbook;
     *     const worksheet = event.worksheet;
     * });
     * ```
     */
    readonly CrosshairHighlightEnabledChanged: 'CrosshairHighlightEnabledChanged';
    /**
     * Triggered when the crosshair highlight color is changed.
     * @example
     * ```ts
     * univerAPI.addEvent(univerAPI.Event.CrosshairHighlightColorChanged, (event) => {
     *     const color = event.color;
     *     const workbook = event.workbook;
     *     const worksheet = event.worksheet;
     * });
     * ```
     */
    readonly CrosshairHighlightColorChanged: 'CrosshairHighlightColorChanged';
}
export interface ICrosshairHighlightEnabledChangedEvent extends IEventBase {
    /**
     * Whether the crosshair highlight is enabled.
     */
    enabled: boolean;
    /**
     * The workbook that the crosshair highlight is enabled in.
     */
    workbook: FWorkbook;
    /**
     * The worksheet that the crosshair highlight is enabled in.
     */
    worksheet: FWorksheet;
}
export interface ICrosshairHighlightColorChangedEvent extends IEventBase {
    /**
     * The color of the crosshair highlight.
     */
    color: string;
    /**
     * The workbook that the crosshair highlight is enabled in.
     */
    workbook: FWorkbook;
    /**
     * The worksheet that the crosshair highlight is enabled in.
     */
    worksheet: FWorksheet;
}
/**
 * @ignore
 */
export declare class FSheetCrosshairHighlightEventMixin implements IFSheetCrosshairHighlightEventMixin {
    get CrosshairHighlightEnabledChanged(): 'CrosshairHighlightEnabledChanged';
    get CrosshairHighlightColorChanged(): 'CrosshairHighlightColorChanged';
}
/**
 * @ignore
 */
export interface ISheetCrosshairHighlightEventConfigs {
    CrosshairHighlightEnabledChanged: ICrosshairHighlightEnabledChangedEvent;
    CrosshairHighlightColorChanged: ICrosshairHighlightColorChangedEvent;
}
/**
 * @ignore
 */
export interface IFUniverCrosshairHighlightMixin {
    /**
     * Enable or disable crosshair highlight.
     * @param {boolean} enabled if crosshair highlight should be enabled
     * @returns {FUniver} the FUniver instance
     * @example
     * ```ts
     * univer.setCrosshairHighlightEnabled(true);
     * ```
     */
    setCrosshairHighlightEnabled(enabled: boolean): FUniver;
    /**
     * Set the color of the crosshair highlight.
     * @param {string} color the color of the crosshair highlight
     * @returns {FUniver} the FUniver instance
     * @example
     * ```ts
     * univer.setCrosshairHighlightColor('#FF0000');
     * ```
     */
    setCrosshairHighlightColor(color: string): FUniver;
    /**
     * Get whether the crosshair highlight is enabled.
     * @returns {boolean} whether the crosshair highlight is enabled
     * @example
     * ```ts
     * const enabled = univer.getCrosshairHighlightEnabled();
     * ```
     */
    getCrosshairHighlightEnabled(): boolean;
    /**
     * Get the color of the crosshair highlight.
     * @returns {string} the color of the crosshair highlight
     * @example
     * ```ts
     * const color = univer.getCrosshairHighlightColor();
     * ```
     */
    getCrosshairHighlightColor(): string;
    /**
     * Get the available built-in colors for the crosshair highlight.
     */
    readonly CROSSHAIR_HIGHLIGHT_COLORS: string[];
}
/**
 * @ignore
 */
export declare class FUniverCrosshairHighlightMixin extends FUniver implements IFUniverCrosshairHighlightMixin {
    /**
     * @ignore
     */
    _initialize(injector: Injector): void;
    setCrosshairHighlightEnabled(enabled: boolean): FUniver;
    setCrosshairHighlightColor(color: string): FUniver;
    getCrosshairHighlightEnabled(): boolean;
    getCrosshairHighlightColor(): string;
    get CROSSHAIR_HIGHLIGHT_COLORS(): string[];
}
declare module '@univerjs/core' {
    interface FUniver extends IFUniverCrosshairHighlightMixin {
    }
    interface FEventName extends IFSheetCrosshairHighlightEventMixin {
    }
    interface IEventParamConfig extends ISheetCrosshairHighlightEventConfigs {
    }
}
